@@ -14,10 +14,9 @@ def store_metric(ghClient: Github, dataframe: pd.DataFrame, filepath: str, assig
     branch = branch or get_valid_branch_name(file_path)
 
     repo = ghClient.get_repo(repo_orga + "/" + repo_name)
-    assert_default_branchs_exist(repo)
     dataframe = sort_dataframe_on_first_column_and_assert_is_unique(dataframe)
-    # Push metric on the metric branch
-    push_metric(dataframe, assignees, 'reported',
+
+    push_metric(dataframe, assignees, repo.default_branch,
                 branch, store_json, file_path, repo)
 
 
@@ -27,8 +26,6 @@ def push_metric(dataframe, assignees, reported_branch, computed_branch, store_js
         print("Metric not found, creating it on branch: " + reported_branch)
         create_file_on_branch(file_path, repo, reported_branch,
                               dataframe, assignees, store_json)
-        # TODO Cherry pick commit from branch and push it on reported branch
-
         pass
     else:
         print("Metric found, updating it on branch: " + reported_branch)
@@ -59,7 +56,7 @@ def push_metric(dataframe, assignees, reported_branch, computed_branch, store_js
                                  dataframe, store_json)
                 print("Drift pushed")
                 print("Creating pull request")
-                create_pullrequest(repo, computed_branch, assignees)
+                create_pullrequest(repo, computed_branch, assignees, file_path)
 
     pass
 
@@ -78,14 +75,14 @@ def assert_file_exists(repo: Repository.Repository, file_path: str, ref: str) ->
 
 
 def push_new_lines(file_path: str, repo: Repository.Repository, branch: str, dataframe: pd.DataFrame, store_json: bool):
-    commit_message = "New metric: " + file_path
+    commit_message = "New data: " + file_path
     print("Commit: " + commit_message)
     update_file_with_retry(repo, file_path, commit_message,
                            dataframe.to_csv(index=False, header=True), branch)
 
     if store_json:
         json_file_path = file_path.replace(".csv", ".json")
-        json_commit_message = "New metric (json): " + json_file_path
+        json_commit_message = "New data (json): " + json_file_path
         json_data = dataframe.to_json(
             orient="records", lines=True, date_format="iso")
         update_file_with_retry(repo, json_file_path,
@@ -129,21 +126,21 @@ def update_file_with_retry(repo: Repository.Repository, file_path, commit_messag
 
 
 def create_file_on_branch(file_path: str, repo: Repository.Repository, branch: str, dataframe: pd.DataFrame, assignees: List[str], store_json: bool):
-    commit_message = "New metric: " + file_path
+    commit_message = "New data: " + file_path
     print("Commit: " + commit_message)
     repo.create_file(file_path, commit_message, dataframe.to_csv(
         index=False, header=True), branch)
     if store_json:
         json_file_path = file_path.replace(".csv", ".json")
-        repo.create_file(json_file_path, "New metric (json): " +
+        repo.create_file(json_file_path, "New data (json): " +
                          file_path, dataframe.to_json(orient="records", lines=True, date_format="iso"), branch)
 
 
-def create_pullrequest(repo: Repository.Repository, branch: str, assignees: List[str]):
+def create_pullrequest(repo: Repository.Repository, branch: str, assignees: List[str], file_path: str):
     try:
         if len(assignees) > 0:
             pullrequest = repo.create_pull(
-                title="New data", body="New data available", head=branch, base=repo.default_branch)
+                title="New drift detected "+file_path, body="A new drift has been detecte", head=branch, base=repo.default_branch)
             print("Pull request created: " + pullrequest.html_url)
             existing_assignees = assert_assignees_exists(repo, assignees)
             pullrequest.add_to_assignees(*existing_assignees)
@@ -206,7 +203,7 @@ def create_git_branch(repo: Repository.Repository, branch_name: str):
     Creates a new Git branch with the given name in the given repository.
     """
     # Get the default branch of the repository
-    reported_branch = repo.get_branch('reported')
+    reported_branch = repo.get_branch(repo.default_branch)
 
     # Create a new reference to the default branch
     ref = repo.create_git_ref(
@@ -215,28 +212,6 @@ def create_git_branch(repo: Repository.Repository, branch_name: str):
     return ref
 
 
-def assert_default_branchs_exist(repo: Repository.Repository):
-    """
-    Checks if the 'computed' and 'reported' branches exist in the given repository,
-    and creates them if they don't.
-    """
-    try:
-        repo.get_branch('reported')
-    except GithubException:
-        create_git_branch(repo, 'reported')
-        try:
-            repo.edit(default_branch='reported')
-        except GithubException as e:
-            print(f"Failed to set default branch: {e}")
-
-    try:
-        repo.get_branch('computed')
-    except GithubException:
-        create_git_branch(repo, 'computed')
-
-# Panda helpers
-
-
 def find_date_column(df):
     date_columns = df.filter(like='date').columns
     if len(date_columns) > 0:
